@@ -361,7 +361,7 @@ ENDXX:   ;
 
 /*void SPU_async(unsigned long cycle)
 {
- 	if( iSoundMuted > 0 ) return;
+ 	if( iSoundMuted != 0 ) return;
 	int i;
 	int t=(cycle?20:16); // cycle 0=NTSC 16 ms, 1=PAL 20 ms
  	for (i=0;i<t;i++)
@@ -379,7 +379,7 @@ void SPU_async(unsigned long cycle)
  	int myt = gp2x_timer_read()-last_time;
  	last_time = gp2x_timer_read();
 
- 	if( iSoundMuted > 0 ) return;
+ 	if( iSoundMuted != 0 ) return;
 	int t=(cycle?20:16);
 
 	for(int i=0; i<t; i++) scale[i] = 0;
