@@ -63,8 +63,8 @@ void about_dialog(GtkWindow* parent)
 	GtkWidget* separator1 = gtk_hseparator_new();
 	GtkWidget* separator2 = gtk_hseparator_new();
 	GtkWidget* url_label = gtk_link_button_new("http://github.com/smokku/psx4all");
-	GtkWidget* upstream_label = gtk_label_new("Kudos to ZodTTD for original psx4all.");
-	GtkWidget* thanks_label = gtk_label_new("Many thanks to all of maemo.org for their help.");
+	GtkWidget* upstream_label = gtk_label_new("Credits: UNAI - ZODTTD - HLIDE - CHUI - TINNUS");
+	GtkWidget* thanks_label = gtk_label_new("Banner image by nax3000.\nMany thanks to all of maemo.org for their help.");
 
 #if MAEMO_VERSION >= 5
 	hildon_gtk_widget_set_theme_size(url_label, HILDON_SIZE_FINGER_HEIGHT);
