@@ -11,6 +11,7 @@ extern int skipCount;
 extern int skipRate;
 extern int iSoundMuted;
 extern int linesInterlace_user;
+extern int PsxCycleMult;
 extern gboolean enableFrameLimit;
 extern gboolean enableAbbeyHack;
 extern gboolean displayFrameInfo;
@@ -24,6 +25,14 @@ extern gboolean hardframeskip_image;
 extern gboolean hardframeskip_blit;
 extern gboolean use_wall_clock_time;
 
+typedef struct ButtonEntry {
+	const char * gconf_key;
+	unsigned long keycode;
+} ButtonEntry;
+
+extern unsigned long gp2x_keys[256];
+extern ButtonEntry buttons[];
+
 struct _gui_data gui_data;
 
 int destroy = 0;
@@ -66,14 +75,55 @@ void gui_destroy_main_window() {
 	int skipValue = gconf_client_get_int(gui_data.gcc, kGConfFrameSkip, NULL);
 	skipCount = skipCountTable[skipValue];
 	skipRate = skipRateTable[skipValue];
-/*	enableAbbeyHack = !enableAbbeyHack;
-	hardframeskip_line = !hardframeskip_line;
-	hardframeskip_poly = !hardframeskip_poly;
-	hardframeskip_sprite = !hardframeskip_sprite;
-	hardframeskip_image = !hardframeskip_image;
-	hardframeskip_blit = !hardframeskip_blit;
-	use_wall_clock_time = !use_wall_clock_time;
-*/
+	PsxCycleMult = gconf_client_get_int(gui_data.gcc, kGConfCycleMultiplier, NULL) + 1;
+	hardframeskip_line = gconf_client_get_bool(gui_data.gcc, kGConfFrameSkipLine, NULL);
+	hardframeskip_poly = gconf_client_get_bool(gui_data.gcc, kGConfFrameSkipPoly, NULL);
+	hardframeskip_sprite = gconf_client_get_bool(gui_data.gcc, kGConfFrameSkipSprite, NULL);
+	hardframeskip_image = gconf_client_get_bool(gui_data.gcc, kGConfFrameSkipImage, NULL);
+	hardframeskip_blit = gconf_client_get_bool(gui_data.gcc, kGConfFrameSkipBlit, NULL);
+	use_wall_clock_time = gconf_client_get_bool(gui_data.gcc, kGConfWallClock, NULL);
+	enableAbbeyHack = gconf_client_get_bool(gui_data.gcc, kGConfAbbeyFix, NULL);
+#if 0
+#define VAL_DEBUG(val) g_print(#val": %d\n", val);
+	VAL_DEBUG(displayGpuStats);
+	VAL_DEBUG(displayVideoMemory);
+	VAL_DEBUG(activeNullGPU);
+	VAL_DEBUG(linesInterlace_user);
+	VAL_DEBUG(enableFrameLimit);
+	VAL_DEBUG(skipCount);
+	VAL_DEBUG(skipRate);
+	VAL_DEBUG(PsxCycleMult);
+	VAL_DEBUG(hardframeskip_line);
+	VAL_DEBUG(hardframeskip_poly);
+	VAL_DEBUG(hardframeskip_sprite);
+	VAL_DEBUG(hardframeskip_image);
+	VAL_DEBUG(hardframeskip_blit);
+	VAL_DEBUG(use_wall_clock_time);
+	VAL_DEBUG(enableAbbeyHack);
+#ifndef NOSOUND
+	VAL_DEBUG(iSoundMuted);
+#endif
+#endif
+
+
+	/* Load Player Keymap */
+	// Build player 1 keyboard gconf key relative path
+	gchar key[kGConfPlayerPathBufferLen];
+	gchar *relKey = key + sprintf(key,
+		kGConfPlayerPath kGConfPlayerKeyboardPath "/", 1);
+
+	memset(gp2x_keys, 0, sizeof(gp2x_keys));
+
+	int i, scancode;
+	for (i = 0; buttons[i].gconf_key; i++) {
+		strcpy(relKey, buttons[i].gconf_key);
+		scancode = gconf_client_get_int(gui_data.gcc, key, NULL);
+
+		if (scancode & 0xff != scancode) continue;
+
+		gp2x_keys[scancode] = buttons[i].keycode;
+	}
+
 	/* and close the GUI */
 	destroy = 1;
 	gtk_widget_destroy(gui_data.window);
@@ -128,15 +178,19 @@ static void select_rom_callback(GtkWidget * button, gpointer data)
 
 	filter = gtk_file_filter_new();
 	gtk_file_filter_add_pattern(filter, "*.bin");
+	gtk_file_filter_add_pattern(filter, "*.bin.z");
 	gtk_file_filter_add_pattern(filter, "*.cbn");
 	gtk_file_filter_add_pattern(filter, "*.img");
-	gtk_file_filter_add_pattern(filter, "*.mdf");
 	gtk_file_filter_add_pattern(filter, "*.iso");
+	gtk_file_filter_add_pattern(filter, "*.mdf");
+	gtk_file_filter_add_pattern(filter, "*.znx");
 	gtk_file_filter_add_pattern(filter, "*.BIN");
+	gtk_file_filter_add_pattern(filter, "*.BIN.Z");
 	gtk_file_filter_add_pattern(filter, "*.CBN");
 	gtk_file_filter_add_pattern(filter, "*.IMG");
-	gtk_file_filter_add_pattern(filter, "*.MDF");
 	gtk_file_filter_add_pattern(filter, "*.ISO");
+	gtk_file_filter_add_pattern(filter, "*.MDF");
+	gtk_file_filter_add_pattern(filter, "*.ZNX");
 
 	dialog = hildon_file_chooser_dialog_new_with_properties(
 		get_parent_window(),
@@ -213,13 +267,17 @@ void gui_select_game()
 	/* Add widgets */
 	gui_data.grid = gtk_vbox_new(FALSE, HILDON_MARGIN_DEFAULT);
 
+	/* Banner image */
+	GtkWidget *image = gtk_image_new_from_file ("/usr/share/psx4all/psx4all_banner.jpg");
+	gtk_box_pack_start(GTK_BOX(gui_data.grid), GTK_WIDGET(image), FALSE, FALSE, 0);
+
 	/* Select ROM button */
 	gui_data.select_rom_btn = HILDON_BUTTON(hildon_button_new_with_text(
 		HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_THUMB_HEIGHT,
 		HILDON_BUTTON_ARRANGEMENT_VERTICAL,
 		_("ROM…"),
 		NULL));
-	hildon_button_set_alignment(gui_data.select_rom_btn, 0.0f, 0.5f, 0.9f, 0.2f);
+	hildon_button_set_alignment(gui_data.select_rom_btn, 0.0f, 0.5f, 0.9f, 0.1f);
 	gtk_box_pack_start(GTK_BOX(gui_data.grid), GTK_WIDGET(gui_data.select_rom_btn), FALSE, FALSE, 0);
 
 	/* First row of widgets */
